@@ -4,12 +4,14 @@
     Routines to create markdown documents for Jupyter notebooks, PDF files, and some other useful stuff
 """
 
-from pylatex.utils import italic, bold
+import pylatex
+import matplotlib
+#from pylatex.utils import italic, bold
 from datetime import date
-from pylatex import Document, Section, Subsection, Tabular, Math, TikZ, Axis, \
-    Plot, Figure, Matrix, Alignat, Quantity, MiniPage, LargeText, LineBreak, \
-    MediumText, PageStyle, Head, simple_page_number, Foot
-import matplotlib.image as mpimg
+# from pylatex import Document, Section, Subsection, Tabular, Math, TikZ, Axis, \
+#     Plot, Figure, Matrix, Alignat, Quantity, MiniPage, LargeText, LineBreak, \
+#     MediumText, PageStyle, Head, simple_page_number, Foot
+# import matplotlib.image as mpimg
 import math
 import numpy as np
 import matplotlib.pyplot as plt
@@ -341,11 +343,11 @@ def imgplot(X, Y, XXYY, cs='b-', imgfile="", ax=[], xticks=[], yticks=[]):
 
     This example draws lines on the following reference chart:
         
-        .. image::  ../../pics/ashby_strength_density_chart.png
+        .. image::  ../../assets/ashby_strength_density_chart.png
         
     To create the following plot:
         
-        .. image:: ../../pics/imgplot.png
+        .. image:: ../../assets/imgplot.png
     
     """
     def ptransform(XY, XXYY, xxyy):
@@ -363,7 +365,7 @@ def imgplot(X, Y, XXYY, cs='b-', imgfile="", ax=[], xticks=[], yticks=[]):
         y = y2-(Y2-Y)/(Y2-Y1)*(y2-y1)
         return (x, y)
     if ax == []:
-        img = mpimg.imread(imgfile)
+        img = matplotlib.image.mpimg.imread(imgfile)
         f1 = plt.figure()
         ax = f1.add_subplot(111)
         ax.imshow(img)
@@ -549,17 +551,10 @@ class mdx:
         
             SECTION=len(TOC)
             MD=mdx(Chapter, SECTION, TOC[SECTION-1])
-            MD.write("Anderson, P., Fouad, A., John Wiley & Sons, publisher, Institute of Electrical Electronics Engineers, & \
-            IEEE Xplore , distributor. (2002). Power system control and stability (2nd ed., IEEE Press power engineering series). \
-            Piscataway, New Jersey: IEEE Press\\n\\n")
-            MD.write("Grigsby, L. (2012). The electric power engineering handbook. Power system stability and control (3rd ed.). \
-            Boca Raton, FL: CRC Press.\\n\\n")
-            MD.write("IEEE Sub-synchronous resonance working group, Second benchmark model for computer simulation of sub-synchronous \
-            resonance, IEEE Transactions on Power Apparatus and Systems, vol. PAS-104, no. 5, pp. 1057-1066 (1985)\\n\\n")
-            MD.write("Kundur, P, Power System Stability and Control, Mc-Graw-Hill (1994)\\n\\n")
-            MD.write("Liwschitz, M M (1941). Positive and Negative Damping in Synchronous Machines, Electrical Engineering, \
-            60(5), 210-213. doi: 10.1109/EE.1941.6432110\\n\\n")
-            MD.write("Wilti, T (2000). Elecrical Machines, Drives, and Power Systems, 4th ed. Prentice Hall.\\n\\n")
+            MD.write("Robert L. Mott, MECH2100 Machine Design (Custom Edition)\\n\\n")
+            MD.write("Ashby, M.F., 2011.   Materials selection in mechanical design, Butterworth-Heinemann, Oxford, OX ; Boston, MA . \
+            (Electronic resource, Call Number:TA403.6 .A74 2011eb )\\n\\n")
+            MD.write("Standards Australia, 1993.  Engineering Drawing Handbook SAA HB7, Standards Association of Australia, (Call Number:T357 .M43 1993 )\\n\\n")
             md(MD.out())
             
         Read the following information on the `` write()`` method to see how you can 
@@ -1264,9 +1259,9 @@ def createx(title, subtitle):
 
     # Add Heading
     with doc.create(MiniPage(align='c')):
-        doc.append(LargeText(bold(title)))
+        doc.append(LargeText(pylatex.utils.bold(title)))
         doc.append(LineBreak())
-        doc.append(MediumText(bold(subtitle)))
+        doc.append(MediumText(pylatex.utils.bold(subtitle)))
     return doc
 
 
@@ -1323,7 +1318,7 @@ def sapp(p, s):
                 if (i % 2) == 0:
                     p.append(y)
                 else:
-                    p.append(italic(y+" "))
+                    p.append(pylatex.utils.italic(y+" "))
             else:
                 mathema(p, y)
 #                alignat(p,y)
@@ -1332,4 +1327,4 @@ def sapp(p, s):
         i += 1
 
 def xtver():
-    return 1
\ No newline at end of file
+    return "4:17pm 3 June 2021"
\ No newline at end of file
